@@ -3,9 +3,7 @@ from miio.protocol import Message, Utils
 from miio.vacuumcontainers import (VacuumStatus, ConsumableStatus, DNDStatus,
                                    CleaningDetails, CleaningSummary, Timer)
 from miio.vacuum import Vacuum, VacuumException
-from miio.plug import Plug
-from miio.plug_v1 import PlugV1
-from miio.plug_v3 import PlugV3
+from miio.chuangmi_plug import (Plug, PlugV1, PlugV3, ChuangmiPlug)
 from miio.airpurifier import AirPurifier
 from miio.airhumidifier import AirHumidifier
 from miio.waterpurifier import WaterPurifier
@@ -16,6 +14,7 @@ from miio.philips_eyecare import PhilipsEyecare
 from miio.chuangmi_ir import ChuangmiIr
 from miio.fan import Fan
 from miio.wifispeaker import WifiSpeaker
+from miio.wifirepeater import WifiRepeater
 from miio.airqualitymonitor import AirQualityMonitor
 from miio.airconditioningcompanion import AirConditioningCompanion
 from miio.yeelight import Yeelight
