@@ -1,7 +1,11 @@
-from .device import Device
 from typing import Tuple, Optional
 from enum import IntEnum
 import warnings
+from .device import Device, DeviceException
+
+
+class YeelightException(DeviceException):
+    pass
 
 
 class YeelightMode(IntEnum):
@@ -30,7 +34,7 @@ class YeelightStatus:
     def rgb(self) -> Optional[Tuple[int, int, int]]:
         """Return color in RGB if RGB mode is active."""
         if self.color_mode == YeelightMode.RGB:
-            rgb = self.data["rgb"]
+            rgb = int(self.data["rgb"])
             blue = rgb & 0xff
             green = (rgb >> 8) & 0xff
             red = (rgb >> 16) & 0xff
@@ -97,71 +101,13 @@ class Yeelight(Device):
     (https://yeelight.readthedocs.io/en/latest/),
     which however requires enabling the developer mode on the bulbs.
     """
+
     def __init__(self, *args, **kwargs):
         warnings.warn("Please consider using python-yeelight "
                       "for more complete support.", stacklevel=2)
         super().__init__(*args, **kwargs)
 
-    def on(self):
-        """Power on."""
-        """
-        set_power ["on|off", "smooth", time_in_ms, mode]
-        where mode:
-        0: last mode
-        1: normal mode
-        2: rgb mode
-        3: hsv mode
-        4: color flow
-        5: moonlight
-        """
-        return self.send("set_power", ["on"])
-
-    def off(self):
-        """Power off."""
-        return self.send("set_power", ["off"])
-
-    def set_brightness(self, bright):
-        """Set brightness."""
-        return self.send("set_bright", [bright])
-
-    def set_color_temp(self, ct):
-        """Set color temp in kelvin."""
-        return self.send("set_ct_abx", [ct, "smooth", 500])
-
-    def set_rgb(self, rgb):
-        """Set color in encoded RGB."""
-        return self.send("set_rgb", [rgb])
-
-    def set_hsv(self, hsv):
-        """Set color in HSV."""
-        return self.send("set_hsv", [hsv])
-
-    def set_developer_mode(self, enable: bool) -> bool:
-        """Enable or disable the developer mode."""
-        return self.send("set_ps", ["cfg_lan_ctrl", str(int(enable))])
-
-    def set_save_state_on_change(self, enable: bool) -> bool:
-        """Enable or disable saving the state on changes."""
-        return self.send("set_ps", ["cfg_save_state"], str(int(enable)))
-
-    def set_name(self, name: str) -> bool:
-        """Set an internal name for the bulb."""
-        return self.send("set_name", [name])
-
-    def toggle(self):
-        """Toggle bulb state."""
-        return self.send("toggle")
-
-    def set_default(self):
-        """Set current state as default."""
-        return self.send("set_default")
-
-    def set_scene(self, scene, *vals):
-        """Set the scene."""
-        raise NotImplementedError("Setting the scene is not implemented yet.")
-        # return self.send("set_scene", [scene, *vals])
-
-    def status(self):
+    def status(self) -> YeelightStatus:
         """Retrieve properties."""
         properties = [
             "power",
@@ -183,5 +129,68 @@ class Yeelight(Device):
 
         return YeelightStatus(dict(zip(properties, values)))
 
+    def on(self):
+        """Power on."""
+        """
+        set_power ["on|off", "smooth", time_in_ms, mode]
+        where mode:
+        0: last mode
+        1: normal mode
+        2: rgb mode
+        3: hsv mode
+        4: color flow
+        5: moonlight
+        """
+        return self.send("set_power", ["on"])
+
+    def off(self):
+        """Power off."""
+        return self.send("set_power", ["off"])
+
+    def set_brightness(self, bright):
+        """Set brightness."""
+        if bright < 0 or bright > 100:
+            raise YeelightException("Invalid brightness: %s" % bright)
+        return self.send("set_bright", [bright])
+
+    def set_color_temp(self, ct):
+        """Set color temp in kelvin."""
+        if ct > 6500 or ct < 1700:
+            raise YeelightException("Invalid color temperature: %s" % ct)
+        return self.send("set_ct_abx", [ct, "smooth", 500])
+
+    def set_rgb(self, rgb):
+        """Set color in encoded RGB."""
+        return self.send("set_rgb", [rgb])
+
+    def set_hsv(self, hsv):
+        """Set color in HSV."""
+        return self.send("set_hsv", [hsv])
+
+    def set_developer_mode(self, enable: bool) -> bool:
+        """Enable or disable the developer mode."""
+        return self.send("set_ps", ["cfg_lan_ctrl", str(int(enable))])
+
+    def set_save_state_on_change(self, enable: bool) -> bool:
+        """Enable or disable saving the state on changes."""
+        return self.send("set_ps", ["cfg_save_state", str(int(enable))])
+
+    def set_name(self, name: str) -> bool:
+        """Set an internal name for the bulb."""
+        return self.send("set_name", [name])
+
+    def toggle(self):
+        """Toggle bulb state."""
+        return self.send("toggle")
+
+    def set_default(self):
+        """Set current state as default."""
+        return self.send("set_default")
+
+    def set_scene(self, scene, *vals):
+        """Set the scene."""
+        raise NotImplementedError("Setting the scene is not implemented yet.")
+        # return self.send("set_scene", [scene, *vals])
+
     def __str__(self):
         return "<Yeelight at %s: %s>" % (self.ip, self.token)
